@@ -8,10 +8,7 @@ use vars qw/$VERSION @ISA @EXPORT_OK/;
 @ISA = 'Exporter';
 @EXPORT_OK = qw( encode_ytext decode_ytext validate_ytext);
 
-use encoding "utf-8";
-
-
-$VERSION="0.1.1_1";
+$VERSION="0.2";
 
 =head1 NAME
 
@@ -19,7 +16,7 @@ Convert::YText - Quotes strings suitably for rfc2822 local part
 
 =head1 VERSION
 
-Version 0.1
+Version 0.2
 
 =head1 SYNOPSIS
 
@@ -256,10 +253,6 @@ under the same terms as Perl itself.
 
 L<MIME::Base64>, L<MIME::Decoder::Base64>, L<MIME::Decoder::QuotedPrint>.
 
-=head1 ACKNOWLEDGEMENTS
-
-Thanks to jawnsy for encouraging me to OO-ize the module.
-
 =cut
 
 1;
